@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2013 W. Trevor King <wking@tremily.us>
+# Copyright (C) 2012-2014 W. Trevor King <wking@tremily.us>
 #
 # This file is part of update-copyright.
 #
@@ -26,10 +26,6 @@ import time as _time
 from . import LOG as _LOG
 from . import utils as _utils
 from .vcs.git import GitBackend as _GitBackend
-try:
-    from .vcs.bazaar import BazaarBackend as _BazaarBackend
-except ImportError as _bazaar_import_error:
-    _BazaarBackend = None
 try:
     from .vcs.mercurial import MercurialBackend as _MercurialBackend
 except ImportError as _mercurial_import_error:
@@ -88,10 +84,6 @@ class Project (object):
                 }
             if vcs == 'Git':
                 self._vcs = _GitBackend(**kwargs)
-            elif vcs == 'Bazaar':
-                if _BazaarBackend is None:
-                    raise _bazaar_import_error
-                self._vcs = _BazaarBackend(**kwargs)
             elif vcs == 'Mercurial':
                 if _MercurialBackend is None:
                     raise _mercurial_import_error
@@ -185,14 +177,14 @@ class Project (object):
         _LOG.info('update {}'.format(filename))
         contents = _utils.get_contents(
             filename=filename, unicode=True, encoding=self._encoding)
-        original_year = self._vcs.original_year(filename=filename)
+        years = self._vcs.years(filename=filename)
         authors = self._vcs.authors(filename=filename)
         new_contents = _utils.update_copyright(
-            contents=contents, original_year=original_year, authors=authors,
+            contents=contents, years=years, authors=authors,
             text=self._copyright, info=self._info(), prefix=('# ', '# ', None),
             width=self._width, tag=self._copyright_tag)
         new_contents = _utils.update_copyright(
-            contents=new_contents, original_year=original_year,
+            contents=new_contents, years=years,
             authors=authors, text=self._copyright, info=self._info(),
             prefix=('/* ', ' * ', ' */'), width=self._width,
             tag=self._copyright_tag)
@@ -215,28 +207,27 @@ class Project (object):
             return
         _LOG.info('update pyfile at {}'.format(self._pyfile))
         current_year = _time.gmtime()[0]
-        original_year = self._vcs.original_year()
+        years = self._vcs.years()
         authors = self._vcs.authors()
         lines = [
             _utils.copyright_string(
-                original_year=original_year, final_year=current_year,
-                authors=authors, text=self._copyright, info=self._info(),
-                prefix=('# ', '# ', None), width=self._width),
+                years=years, authors=authors, text=self._copyright,
+                info=self._info(), prefix=('# ', '# ', None),
+                width=self._width),
             '', 'import textwrap as _textwrap', '', '',
             'LICENSE = """',
             _utils.copyright_string(
-                original_year=original_year, final_year=current_year,
-                authors=authors, text=self._copyright, info=self._info(),
-                prefix=('', '', None), width=self._width),
+                years=years, authors=authors, text=self._copyright,
+                info=self._info(), prefix=('', '', None), width=self._width),
             '""".strip()',
             '',
             'def short_license(info, wrap=True, **kwargs):',
             '    paragraphs = [',
             ]
         paragraphs = _utils.copyright_string(
-            original_year=original_year, final_year=current_year,
-            authors=authors, text=self._short_copyright, info=self._info(),
-            author_format_fn=_utils.short_author_formatter, wrap=False,
+            years=years, authors=authors, text=self._short_copyright,
+            info=self._info(), author_format_fn=_utils.short_author_formatter,
+            wrap=False,
             ).split('\n\n')
         for p in paragraphs:
             lines.append("        '{}'.format(**info),".format(
